==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/application.h <==
#ifndef APPLICATION_H
#define APPLICATION_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfig.h>
#include <subtitle.h>
#include <audiolevels.h>
#include "useractions/useraction.h"

#include <kapplication.h>

#include <qptrlist.h>
#include <qmap.h>

class KComboBox;
class KAction;
class KRecentFilesActionExt;

namespace SubtitleComposer
{
	class Player;
	class AudioLevels;

	class MainWindow;
	class AudioLevelsWidget;
	class PlayerWidget;
	class LinesWidget;
	class CurrentLineWidget;
	class ConfigDialog;
	class ErrorsDialog;
	class ErrorsWidget;

	class Find;
	class Replace;
	class FindError;
	class Spelling;

	class Application : public KApplication
	{
		Q_OBJECT

		public:

			Application();
			virtual ~Application();

			static Application* instance();

			void loadConfig();
			void saveConfig();

			AppConfigGroup* generalConfig();
			AppConfigGroup* errorsConfig();
			AppConfigGroup* playerConfig();

			KAction* action( const char* actionName );
			void triggerAction( const KShortcut& shortCut );

			const QStringList& availableEncodingNames() const;

			const QString& lastSubtitleDirectory() const;

		public slots:

			/// BEGIN ACTIONS HANDLERS

			void undo();
			void redo();

			void newSubtitle();
			void openSubtitle();
			void openSubtitle( const KURL& url );
			void openSubtitle( const QString& encoding );
			bool saveSubtitle();
			bool saveSubtitleAs();
			bool closeSubtitle();

			void newTrSubtitle();
			void openTrSubtitle();
			void openTrSubtitle( const KURL& url );
			bool saveTrSubtitle();
			bool saveTrSubtitleAs();
			bool closeTrSubtitle();

			void joinSubtitles();
			void splitSubtitle();

			void insertBeforeCurrentLine();
			void insertAfterCurrentLine();
			void removeSelectedLines();

			void joinSelectedLines();
			void splitSelectedLines();

			void selectAllLines();
			void gotoLine();

			void find();
			void findNext();
			void findPrevious();
			void replace();

			void spellCheck();

			void findNextError();
			void findPreviousError();

			void checkErrors();
			void recheckAllErrors();
			void recheckSelectedErrors();
			void clearErrors();
			void clearAllErrors();
			void clearSelectedErrors();
			void clearAllMarks();
			void clearSelectedMarks();

			void showErrors();
			void showErrorsConfig();

			void toggleSelectedLinesMark();
			void toggleSelectedLinesBold();
			void toggleSelectedLinesItalic();
			void toggleSelectedLinesUnderline();

			void shiftLines();
			void shiftSelectedLinesForwards();
			void shiftSelectedLinesBackwards();
			void adjustLines();

			void sortLines();

			void changeFrameRate();
			void durationLimits();
			void autoDurations();
			void maximizeDurations();
			void fixOverlappingLines();
			void syncWithSubtitle();

			void adjustTexts();
			void unbreakTexts();
			void simplifySpaces();
			void changeCase();
			void fixPunctuation();

			void openVideo();
			void openVideo( const KURL& url );

			void toggleFullScreenMode();
			void setFullScreenMode( bool enabled );

			void seekBackwards();
			void seekForwards();
			void seekToPrevLine();
			void seekToNextLine();

			void setCurrentLineShowTimeFromVideo();
			void setCurrentLineHideTimeFromVideo();

			void shiftToVideoPosition();
			void adjustToVideoPositionAnchorLast();
			void adjustToVideoPositionAnchorFirst();

			void openAudioLevels();
			void openAudioLevels( const KURL& url );
			void saveAudioLevelsAs();
			void closeAudioLevels();

			void increaseAudioLevelsVZoom();
			void decreaseAudioLevelsVZoom();
			void increaseAudioLevelsHZoom();
			void decreaseAudioLevelsHZoom();

			/// END ACTIONS HANDLERS

		signals:

			void subtitleOpened( Subtitle* subtitle );
			void subtitleClosed();

			void audiolevelsOpened( AudioLevels* audiolevels );
			void audiolevelsClosed();

			void translationModeChanged( bool value );
			void fullScreenModeChanged( bool value );

		private:

			bool checkDifferentNames( const QString& subtitlePath, const QString& subtitleTrPath );

			KURL saveSplittedSubtitle( const Subtitle& subtitle, const QString& srcPath, QString encoding, QString format, bool primary );

			void setupActions();

			Time videoPosition( bool compensate=false );

			QMap<QString,QString> generalConfigDefaults();
			QMap<QString,QString> errorsConfigDefaults();
			QMap<QString,QString> playerConfigDefaults();

			static const QString& buildMediaFilesFilter();
			static const QString& buildLevelsFilesFilter();

		private slots:

			void updateTitle();

			void onLineDoubleClicked( SubtitleLine* line );
			void onHighlightLine( SubtitleLine* line, bool primary=true, int firstIndex=-1, int lastIndex=-1 );
			void onPlayingLineChanged( SubtitleLine* line );
			void onLinkCurrentLineToVideoToggled( bool value );

			void onPlayerFileOpened( const QString& filePath );
			void onPlayerPlaying();
			void onPlayerPaused();
			void onPlayerStopped();
			void onPlayerAudioStreamsChanged( const QStringList& audioStreams );
			void onPlayerActiveAudioStreamChanged( int audioStream );
			void onPlayerMutedChanged( bool muted );
			void onPlayerOptionChanged( const QString& option, const QString& value );

			void setActiveSubtitleStream( int subtitleStream );

			void showConfirmQuit();

			void updateConfigFromDialog();

		private:

			void toggleFullScreen( bool on );

			AppConfig m_config;

			UserActionManager m_actionManager;

			Subtitle* m_subtitle;
			QString m_subtitlePath;
			QString m_subtitleFileName;
			QString m_subtitleEncoding;
			int m_subtitleEOL;
			QString m_subtitleFormat;

			bool m_translationMode;
			QString m_subtitleTrPath;
			QString m_subtitleTrFileName;
			QString m_subtitleTrEncoding;
			int m_subtitleTrEOL;
			QString m_subtitleTrFormat;

			Player* m_player;

			SubtitleLine* m_lastFoundLine;

			AudioLevels* m_audiolevels;

			MainWindow* m_mainWindow;
			AudioLevelsWidget* m_audiolevelsWidget;
			PlayerWidget* m_playerWidget;
			LinesWidget* m_linesWidget;
			CurrentLineWidget* m_curLineWidget;

			ConfigDialog* m_configDialog;
			ErrorsDialog* m_errorsDialog;

			ErrorsWidget* m_errorsWidget;

			QString m_lastSubtitleDir;
			KRecentFilesActionExt* m_recentSubtitlesAction;
			KRecentFilesActionExt* m_recentTrSubtitlesAction;
			KComboBox* m_encodingsComboBox;

			Find* m_find;
			Replace* m_replace;
			FindError* m_findError;
			Spelling* m_spelling;

			QString m_lastVideoDir;
			bool m_linkCurrentLineToPosition;
			KRecentFilesActionExt* m_recentVideosAction;

			QString m_lastAudioLevelsDir;
			KRecentFilesActionExt* m_recentAudioLevelssAction;
	};

	Application* app();
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/application.h <==
#ifndef APPLICATION_H
#define APPLICATION_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfig.h>
#include <subtitle.h>
#include <audiolevels.h>

#include <kapplication.h>
#include <kaction.h>
#include <kurl.h>

#include <qptrlist.h>
#include <qmap.h>

class KComboBox;
class KAction;
class KRecentFilesActionExt;

namespace SubtitleComposer
{
	class Player;
	class AudioLevels;

	class MainWindow;
	class AudioLevelsWidget;
	class PlayerWidget;
	class LinesWidget;
	class CurrentLineWidget;
	class ConfigDialog;
	class ErrorsDialog;
	class ErrorsWidget;

	class Find;
	class Replace;
	class FindError;
	class Spelling;

	class Application : public KApplication
	{
		Q_OBJECT

		public:

			Application();
			virtual ~Application();

			static Application* instance();

			void loadConfig();
			void saveConfig();

			AppConfigGroup* generalConfig();
			AppConfigGroup* errorsConfig();
			AppConfigGroup* playerConfig();

			KAction* action( const char* actionName );
			void triggerAction( const KShortcut& shortCut );

			const QStringList& availableEncodingNames() const;

			const KURL& lastSubtitleDirectory() const;

		public slots:

			/// BEGIN ACTIONS HANDLERS

			void undo();
			void redo();

			void newSubtitle();
			void openSubtitle();
			void openSubtitle( const KURL& url );
			bool saveSubtitle();
			bool saveSubtitleAs();
			bool closeSubtitle();

			void newTrSubtitle();
			void openTrSubtitle();
			void openTrSubtitle( const KURL& url );
			bool saveTrSubtitle();
			bool saveTrSubtitleAs();
			bool closeTrSubtitle();

			void changeSubtitlesEncoding( const QString& encoding );

			void joinSubtitles();
			void splitSubtitle();

			void insertBeforeCurrentLine();
			void insertAfterCurrentLine();
			void removeSelectedLines();

			void joinSelectedLines();
			void splitSelectedLines();

			void selectAllLines();
			void gotoLine();

			void find();
			void findNext();
			void findPrevious();
			void replace();

			void spellCheck();

			void findNextError();
			void findPreviousError();

			void checkErrors();
			void recheckAllErrors();
			void recheckSelectedErrors();
			void clearErrors();
			void clearAllErrors();
			void clearSelectedErrors();
			void clearAllMarks();
			void clearSelectedMarks();

			void showErrors();
			void showErrorsConfig();

			void toggleSelectedLinesMark();
			void toggleSelectedLinesBold();
			void toggleSelectedLinesItalic();
			void toggleSelectedLinesUnderline();
			void toggleSelectedLinesStrikeThrough();

			void shiftLines();
			void shiftSelectedLinesForwards();
			void shiftSelectedLinesBackwards();
			void adjustLines();

			void sortLines();

			void changeFrameRate();
			void durationLimits();
			void autoDurations();
			void maximizeDurations();
			void fixOverlappingLines();
			void syncWithSubtitle();

			void adjustTexts();
			void unbreakTexts();
			void simplifySpaces();
			void changeCase();
			void fixPunctuation();

			void openVideo();
			void openVideo( const KURL& url );

			void toggleFullScreenMode();
			void setFullScreenMode( bool enabled );

			void seekBackwards();
			void seekForwards();
			void seekToPrevLine();
			void seekToNextLine();

			void setCurrentLineShowTimeFromVideo();
			void setCurrentLineHideTimeFromVideo();

			void shiftToVideoPosition();
			void adjustToVideoPositionAnchorLast();
			void adjustToVideoPositionAnchorFirst();

			void openAudioLevels();
			void openAudioLevels( const KURL& url );
			void saveAudioLevelsAs();
			void closeAudioLevels();

			void increaseAudioLevelsVZoom();
			void decreaseAudioLevelsVZoom();
			void increaseAudioLevelsHZoom();
			void decreaseAudioLevelsHZoom();

			/// END ACTIONS HANDLERS

		signals:

			void subtitleOpened( Subtitle* subtitle );
			void subtitleClosed();

			void audiolevelsOpened( AudioLevels* audiolevels );
			void audiolevelsClosed();

			void translationModeChanged( bool value );
			void fullScreenModeChanged( bool value );

		private:

			bool checkDifferentNames( const KURL& subtitleURL, const KURL& subtitleTrURL );

			KURL saveSplittedSubtitle( const Subtitle& subtitle, const KURL& srcURL, QString encoding, QString format, bool primary );

			void setupActions();

			Time videoPosition( bool compensate=false );

			QMap<QString,QString> generalConfigDefaults();
			QMap<QString,QString> errorsConfigDefaults();
			QMap<QString,QString> playerConfigDefaults();

			static const QString& buildMediaFilesFilter();
			static const QString& buildLevelsFilesFilter();

		private slots:

			void updateTitle();

			void onLineDoubleClicked( SubtitleLine* line );
			void onHighlightLine( SubtitleLine* line, bool primary=true, int firstIndex=-1, int lastIndex=-1 );
			void onPlayingLineChanged( SubtitleLine* line );
			void onLinkCurrentLineToVideoToggled( bool value );

			void onPlayerFileOpened( const QString& filePath );
			void onPlayerPlaying();
			void onPlayerPaused();
			void onPlayerStopped();
			void onPlayerAudioStreamsChanged( const QStringList& audioStreams );
			void onPlayerActiveAudioStreamChanged( int audioStream );
			void onPlayerMutedChanged( bool muted );
			void onPlayerOptionChanged( const QString& option, const QString& value );

			void setActiveSubtitleStream( int subtitleStream );

			void showConfirmQuit();

			void updateConfigFromDialog();

		private:

			void toggleFullScreen( bool on );

			AppConfig m_config;

			Subtitle* m_subtitle;
			KURL m_subtitleURL;
			QString m_subtitleFileName;
			QString m_subtitleEncoding;
			int m_subtitleEOL;
			QString m_subtitleFormat;

			bool m_translationMode;
			KURL m_subtitleTrURL;
			QString m_subtitleTrFileName;
			QString m_subtitleTrEncoding;
			int m_subtitleTrEOL;
			QString m_subtitleTrFormat;

			Player* m_player;

			SubtitleLine* m_lastFoundLine;

			AudioLevels* m_audiolevels;

			MainWindow* m_mainWindow;
			AudioLevelsWidget* m_audiolevelsWidget;
			PlayerWidget* m_playerWidget;
			LinesWidget* m_linesWidget;
			CurrentLineWidget* m_curLineWidget;

			ConfigDialog* m_configDialog;
			ErrorsDialog* m_errorsDialog;

			ErrorsWidget* m_errorsWidget;

			KURL m_lastSubtitleURL;
			KRecentFilesActionExt* m_recentSubtitlesAction;
			KRecentFilesActionExt* m_recentTrSubtitlesAction;
			KComboBox* m_encodingsComboBox;

			Find* m_find;
			Replace* m_replace;
			FindError* m_findError;
			Spelling* m_spelling;

			KURL m_lastVideoURL;
			bool m_linkCurrentLineToPosition;
			KRecentFilesActionExt* m_recentVideosAction;

			KURL m_lastAudioLevelsURL;
			KRecentFilesActionExt* m_recentAudioLevelsAction;
	};

	Application* app();
}

#endif
